function [nmers,buckets,buc1,buc2] = diff_nmers_sign(seq1,seq2,len,n)
%DIFF_NMERS_SIGN finds all nmers that have large frequency difference between 
% 2 sequences.
%
%  [NMERS,BUCKETS,BUC1,BUC2]=DIFF_NMERS_SIGN(SEQ1,SEQ2,LEN,N) finds all the top N
%  nmers of length LEN that have large frequency difference between sequence 
%  SEQ1 and sequence SEQ2. It returns the nmer sequences NMERS, the difference
%  between the frequency in SEQ1 and SEQ2 (BUCKETS), the frequency in
%  SEQ1 (BUC1) and the sequence in SEQ2 (BUC2);
%
%  Example:
%      seq1='actccgttcggatttacgt';
%      seq2='accttggattgatgatgatagctcatg';
%      [nmers,buckets,buc1,buc2] = diff_nmers_sign(seq1,seq2,3,10)
%
% See also nmercount, basecount, codoncount, dimercount.
%
% Done by Chi Nguyen 04/19/2005

if nargin < 3
   error('Bioinfo:NotEnoughInputs','Not enough input arguments.'); 
end

% Figure out how much big everything is.
seqLen1 = length(seq1);
numberOfNmers1 = seqLen1 - len + 1;
seqLen2 = length(seq2);
numberOfNmers2 = seqLen2 - len + 1;

% Stash all of the nmers in the array
for count = len:-1:1
    nmers1(:,count) = seq1(count:count+numberOfNmers1-1);
    nmers2(:,count) = seq2(count:count+numberOfNmers2-1);
end

% Look for the unique nmers1
[nmers1 ,i,j] = unique(nmers1,'rows');
numUniqueVals1 = numel(i);
% Use j to calculate multiplicity
buckets1 = accumarray(j,1)/seqLen1;

% Look for the unique nmers2
[nmers2 ,i,j] = unique(nmers2,'rows');
numUniqueVals2 = numel(i);
% Use j to calculate multiplicity
buckets2 = accumarray(j,1)/seqLen2;

% Find the intersection of two sets of nmers
[tnmers,i1,i2]=intersect(nmers1,nmers2,'rows');
tbuckets=buckets1(i1)-buckets2(i2);
b1=buckets1(i1); b2=buckets2(i2);

% Find the XOR of 2 sets of nmers
[xnmers,i3,i4]=setxor(nmers1,nmers2,'rows');
xnmers=[nmers1(i3,:);nmers2(i4,:)];
xbuckets=[buckets1(i3);-buckets2(i4)];
b1=[b1;buckets1(i3);zeros(length(i4),1)]; b2=[b2;zeros(length(i3),1);buckets2(i4)];

% Keep all nmers in tnmers
tnmers=[tnmers;xnmers];
tbuckets=[tbuckets;xbuckets];

% Keep nmers with large different frequency
threshold=0;
id=find(abs(tbuckets) >= threshold);
nmers=tnmers(id,:);
buckets=tbuckets(id);
buc1=b1(id); 
buc2=b2(id);

% Order by frequencies
[bucket,perm] = sort(-abs(buckets));
if length(bucket) < n+1
    buckets = buckets(perm);
    nmers = nmers(perm,:);
    buc1=buc1(perm); 
    buc2=buc2(perm);
else
    buckets = buckets(perm(1:n));
    nmers = nmers(perm(1:n),:);
    buc1=buc1(perm(1:n)); 
    buc2=buc2(perm(1:n));
end
